@@ -23,6 +23,16 @@
 #include "tmaid.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
+/******************************************************************************
+*                                                                             *
+* ja:編集関数群                                                               *
+*                                                                             *
+******************************************************************************/
 /*  ja:ラインバッファを求める
     start,ラインバッファ
       off,現在のy座標
@@ -141,4 +151,9 @@ gint edit_put_mem(TmaidWindow *tmaid,GdkPoint *put,GdkPoint *new,
 gint edit_del_sel_mem(TmaidWindow *tmaid,GdkPoint *start_p,GdkPoint *end_p);
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif
