@@ -146,7 +146,7 @@ replace_dialog (ReplaceString *rp)
                                             G_CALLBACK (gtk_main_quit), NULL);
   /* ja:ボタン */
   button0 = gtk_button_new_with_mnemonic (_("_Replace"));
-  button1 = gtk_button_new_with_mnemonic (_("_All"));
+  button1 = gtk_button_new_with_mnemonic (_("_All Replace"));
   button2 = gtk_button_new_with_label (_("Cancel"));
   g_signal_connect (G_OBJECT (button0), "clicked",
                                 G_CALLBACK (replace_dialog_clicked_ok), rp);
@@ -170,14 +170,13 @@ replace_dialog (ReplaceString *rp)
     gtk_combo_box_append_text (GTK_COMBO_BOX (combo1), replace_text[i]);
   if (find_num > 0)
     {
-      gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo0)->child), find_text[0]);
+      gtk_combo_box_set_active (GTK_COMBO_BOX (combo0), 0);
       gtk_editable_select_region (GTK_EDITABLE (GTK_BIN (combo0)->child),
                                                                         0, -1);
     }
   if (replace_num > 0)
     {
-      gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo1)->child),
-                                                            replace_text[0]);
+      gtk_combo_box_set_active (GTK_COMBO_BOX (combo1), 0);
       gtk_editable_select_region (GTK_EDITABLE (GTK_BIN (combo1)->child),
                                                                         0, -1);
     }
