@@ -21,6 +21,7 @@
 
 
 #include "common.h"
+#include "misc/misc.h"
 
 
 #ifdef __cplusplus
@@ -138,11 +139,11 @@ extern GtkWidget *mdi;                  /* en:MDI */
 extern GtkWidget *status;               /* ja:ステータスウインドウ */
 extern GtkWidget *label_cursor;         /* ja:カーソル座標 */
 extern GtkPositionType n_pos;           /* ja:ノートブックの位置 */
-extern GtkItemFactory *ifactory_menu;   /* ja:メニュー */
-extern GtkItemFactory *ifactory_popup;  /* ja:ポップアップ */
 extern PangoFontDescription *system_font;
 extern GdkColor system_color[12];
 extern GtkTargetEntry targets[4];/* ja:Text maidが提供可能なセレクション */
+extern MiscCreateMenuEntry menu_entries[];
+extern MiscCreateMenuEntry popup_entries[];
 
 
 #ifdef __cplusplus
