@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 *                                                                             *
 ******************************************************************************/
 /* XPM */
-static gchar *tb_new_xpm[] = {
+static const gchar *tb_new_xpm[] = {
 "16 16 4 1",
 "   c None",
 ".  c #000000",
@@ -51,7 +51,7 @@ static gchar *tb_new_xpm[] = {
 
 
 /* XPM */
-static gchar *tb_open_xpm[] = {
+static const gchar *tb_open_xpm[] = {
 "16 16 5 1",
 "   c None",
 ".  c #000000",
@@ -77,7 +77,7 @@ static gchar *tb_open_xpm[] = {
 
 
 /* XPM */
-static gchar *tb_save_xpm[] = {
+static const gchar *tb_save_xpm[] = {
 "16 16 5 1",
 "  c None",
 ". c #000000",
@@ -102,7 +102,7 @@ static gchar *tb_save_xpm[] = {
 "                "};
 
 
-static gchar *tb_prop_xpm[] = {
+static const gchar *tb_prop_xpm[] = {
 "16 16 4 1",
 "  c None",
 ". c #000000",
@@ -126,7 +126,7 @@ static gchar *tb_prop_xpm[] = {
 "                "};
 
 
-static gchar *tb_print_xpm[] = {
+static const gchar *tb_print_xpm[] = {
 "16 16 7 1",
 "   c None",
 ".  c #000000",
@@ -154,7 +154,7 @@ static gchar *tb_print_xpm[] = {
 
 
 /* XPM */
-static gchar *tb_cut_xpm[] = {
+static const gchar *tb_cut_xpm[] = {
 "16 16 5 1",
 "   c None",
 ".  c #000000",
@@ -180,7 +180,7 @@ static gchar *tb_cut_xpm[] = {
 
 
 /* XPM */
-static gchar *tb_copy_xpm[] = {
+static const gchar *tb_copy_xpm[] = {
 "16 16 4 1",
 "   c None",
 ".  c #000000",
@@ -205,7 +205,7 @@ static gchar *tb_copy_xpm[] = {
 
 
 /* XPM */
-static gchar *tb_paste_xpm[] = {
+static const gchar *tb_paste_xpm[] = {
 "16 16 5 1",
 "   c None",
 ".  c #000000",
@@ -231,7 +231,7 @@ static gchar *tb_paste_xpm[] = {
 
 
 /* XPM */
-static gchar *tb_delete_xpm[] = {
+static const gchar *tb_delete_xpm[] = {
 "16 16 2 1",
 "   c None",
 ",  c #0000FF",
@@ -254,7 +254,7 @@ static gchar *tb_delete_xpm[] = {
 
 
 /* XPM */
-static gchar *tb_undo_xpm[] = {
+static const gchar *tb_undo_xpm[] = {
 "16 16 2 1",
 "   c None",
 "-  c #FF0000",
@@ -277,7 +277,7 @@ static gchar *tb_undo_xpm[] = {
 
 
 /* XPM */
-static gchar *tb_redo_xpm[] = {
+static const gchar *tb_redo_xpm[] = {
 "16 16 2 1",
 "   c None",
 ",  c #0000FF",
@@ -300,7 +300,7 @@ static gchar *tb_redo_xpm[] = {
 
 
 /* XPM */
-static gchar *tb_find_xpm[] = {
+static const gchar *tb_find_xpm[] = {
 "16 16 5 1",
 "   c None",
 ".  c #000000",
@@ -326,7 +326,7 @@ static gchar *tb_find_xpm[] = {
 
 
 /* XPM */
-static gchar *tb_replace_xpm[] = {
+static const gchar *tb_replace_xpm[] = {
 "16 16 5 1",
 "   c None",
 ".  c #000000",
@@ -351,23 +351,23 @@ static gchar *tb_replace_xpm[] = {
 "       ,        "};
 
 
-ToolBar toolbar_items[] = {
-/*  0 */ {N_("New"),        tb_new_xpm,     command_new,      NULL, NULL},
-/*  1 */ {N_("Open"),       tb_open_xpm,    command_open,     NULL, NULL},
-/*  2 */ {N_("Save"),       tb_save_xpm,    command_save,     NULL, NULL},
-/*  3 */ {NULL,             NULL,           NULL,             NULL, NULL},
-/*  4 */ {N_("Properties"), tb_prop_xpm,    command_property, NULL, NULL},
-/*  5 */ {NULL,             NULL,           NULL,             NULL, NULL},
-/*  6 */ {N_("Print"),      tb_print_xpm,   command_print,    NULL, NULL},
-/*  7 */ {NULL,             NULL,           NULL,             NULL, NULL},
-/*  8 */ {N_("Cut"),        tb_cut_xpm,     command_cut,      NULL, NULL},
-/*  9 */ {N_("Copy"),       tb_copy_xpm,    command_copy,     NULL, NULL},
-/* 10 */ {N_("Paste"),      tb_paste_xpm,   command_paste,    NULL, NULL},
-/* 11 */ {N_("Delete"),     tb_delete_xpm,  command_delete,   NULL, NULL},
-/* 12 */ {NULL,             NULL,           NULL,             NULL, NULL},
-/* 13 */ {N_("Undo"),       tb_undo_xpm,    command_undo,     NULL, NULL},
-/* 14 */ {N_("Redo"),       tb_redo_xpm,    command_redo,     NULL, NULL},
-/* 15 */ {NULL,             NULL,           NULL,             NULL, NULL},
-/* 16 */ {N_("Find"),       tb_find_xpm,    command_find,     NULL, NULL},
-/* 17 */ {N_("Replace"),    tb_replace_xpm, command_replace,  NULL, NULL},
-/*    */ {(gpointer)-1,     NULL,           NULL,             NULL, NULL}};
+MiscCreateToolbarEntry toolbar_entries[] = {
+{"new",        N_("New"),        tb_new_xpm,     command_new,      NULL, NULL},
+{"open",       N_("Open"),       tb_open_xpm,    command_open,     NULL, NULL},
+{"save",       N_("Save"),       tb_save_xpm,    command_save,     NULL, NULL},
+{"sep1",       NULL,             NULL,           NULL,             NULL, NULL},
+{"properties", N_("Properties"), tb_prop_xpm,    command_property, NULL, NULL},
+{"sep2",       NULL,             NULL,           NULL,             NULL, NULL},
+{"print",      N_("Print"),      tb_print_xpm,   command_print,    NULL, NULL},
+{"sep3",       NULL,             NULL,           NULL,             NULL, NULL},
+{"cut",        N_("Cut"),        tb_cut_xpm,     command_cut,      NULL, NULL},
+{"copy",       N_("Copy"),       tb_copy_xpm,    command_copy,     NULL, NULL},
+{"paste",      N_("Paste"),      tb_paste_xpm,   command_paste,    NULL, NULL},
+{"delete",     N_("Delete"),     tb_delete_xpm,  command_delete,   NULL, NULL},
+{"sep4",       NULL,             NULL,           NULL,             NULL, NULL},
+{"undo",       N_("Undo"),       tb_undo_xpm,    command_undo,     NULL, NULL},
+{"redo",       N_("Redo"),       tb_redo_xpm,    command_redo,     NULL, NULL},
+{"sep5",       NULL,             NULL,           NULL,             NULL, NULL},
+{"find",       N_("Find"),       tb_find_xpm,    command_find,     NULL, NULL},
+{"replace",    N_("Replace"),    tb_replace_xpm, command_replace,  NULL, NULL},
+{NULL,         NULL,             NULL,           NULL,             NULL, NULL}};
